@@ -24,26 +24,6 @@
 // IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-// https://www.scattered-thoughts.net/writing/babys-second-wasm-compiler/
-//
-// https://craftinginterpreters.com/parsing-expressions.html
-//
-// see: https://github.com/rust-lang/rust-analyzer/blob/master/crates/parser/src/parser.rs
-// https://rust-analyzer.github.io/blog/2020/09/16/challeging-LR-parsing.html
-// https://github.com/rust-lang/rust-analyzer/blob/master/docs/dev/syntax.md
-// https://ericlippert.com/2012/06/08/red-green-trees/
-// https://github.com/swiftlang/swift/tree/5e2c815edfd758f9b1309ce07bfc01c4bc20ec23/lib/Syntax
-// https://swift-ast-explorer.com
-// https://github.com/rust-lang/rust-analyzer/blob/cf156a7a43f822e71309e50470ac34363da26727/docs/dev/syntax.md
-// https://github.com/kaleidawave/ezno/blob/8ce921e39c3d4e947063f206347b2932cee456ec/parser/src/lib.rs#L177
-// https://kaleidawave.github.io/posts/sets-types-and-type-checking/
-// https://github.com/m-novikov/tree-sitter-sql/tree/main
-// https://github.com/withered-magic/starpls/tree/79f47e12dab8be650804ce7fa931ee5e1e116eae/crates/starpls_parser/src
-// https://github.com/apache/datafusion-sqlparser-rs -- removes comments and whitespace :/
-
-// rust analyzer has a builtin doc test like thing where you generate snapshot
-// style tests from comments on top of grammar functions
-
 use drop_bomb::DropBomb;
 use event::Event;
 use grammar::OPERATOR_FIRST;
@@ -209,8 +189,7 @@ impl<'t> Parser<'t> {
             return false;
         }
         let n_raw_tokens = match kind {
-            SyntaxKind::COLON_COLON
-            | SyntaxKind::COLON_EQ
+            SyntaxKind::COLON_EQ
             | SyntaxKind::NEQ
             | SyntaxKind::NEQB
             | SyntaxKind::LTEQ
@@ -231,6 +210,147 @@ impl<'t> Parser<'t> {
                 m.complete(self, SyntaxKind::AT_TIME_ZONE);
                 return true;
             }
+            SyntaxKind::IS_NOT_NORMALIZED => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::NOT_KW);
+                if matches!(
+                    self.current(),
+                    SyntaxKind::NFC_KW
+                        | SyntaxKind::NFD_KW
+                        | SyntaxKind::NFKC_KW
+                        | SyntaxKind::NFKD_KW
+                ) {
+                    self.bump_any();
+                }
+                self.bump(SyntaxKind::NORMALIZED_KW);
+                m.complete(self, SyntaxKind::IS_NOT_NORMALIZED);
+                return true;
+            }
+            SyntaxKind::IS_NORMALIZED => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                if matches!(
+                    self.current(),
+                    SyntaxKind::NFC_KW
+                        | SyntaxKind::NFD_KW
+                        | SyntaxKind::NFKC_KW
+                        | SyntaxKind::NFKD_KW
+                ) {
+                    self.bump_any();
+                }
+                self.bump(SyntaxKind::NORMALIZED_KW);
+                m.complete(self, SyntaxKind::IS_NORMALIZED);
+                return true;
+            }
+            SyntaxKind::COLON_COLON => {
+                let m = self.start();
+                self.bump(SyntaxKind::COLON);
+                self.bump(SyntaxKind::COLON);
+                m.complete(self, SyntaxKind::COLON_COLON);
+                return true;
+            }
+            SyntaxKind::IS_JSON => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_JSON);
+                return true;
+            }
+            SyntaxKind::IS_NOT_JSON => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::NOT_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_NOT_JSON);
+                return true;
+            }
+            SyntaxKind::IS_NOT_JSON_OBJECT => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::NOT_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                self.bump(SyntaxKind::OBJECT_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_NOT_JSON_OBJECT);
+                return true;
+            }
+            SyntaxKind::IS_NOT_JSON_ARRAY => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::NOT_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                self.bump(SyntaxKind::ARRAY_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_NOT_JSON_ARRAY);
+                return true;
+            }
+            SyntaxKind::IS_NOT_JSON_VALUE => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::NOT_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                self.bump(SyntaxKind::VALUE_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_NOT_JSON_VALUE);
+                return true;
+            }
+            SyntaxKind::IS_NOT_JSON_SCALAR => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::NOT_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                self.bump(SyntaxKind::SCALAR_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_NOT_JSON_SCALAR);
+                return true;
+            }
+            SyntaxKind::IS_JSON_OBJECT => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                self.bump(SyntaxKind::OBJECT_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_JSON_OBJECT);
+                return true;
+            }
+            SyntaxKind::IS_JSON_ARRAY => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                self.bump(SyntaxKind::ARRAY_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_JSON_ARRAY);
+                return true;
+            }
+            SyntaxKind::IS_JSON_VALUE => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                self.bump(SyntaxKind::VALUE_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_JSON_VALUE);
+                return true;
+            }
+            SyntaxKind::IS_JSON_SCALAR => {
+                let m = self.start();
+                self.bump(SyntaxKind::IS_KW);
+                self.bump(SyntaxKind::JSON_KW);
+                self.bump(SyntaxKind::SCALAR_KW);
+                grammar::opt_json_keys_unique_clause(self);
+                m.complete(self, SyntaxKind::IS_JSON_SCALAR);
+                return true;
+            }
+            SyntaxKind::NOT_SIMILAR_TO => {
+                let m = self.start();
+                self.bump(SyntaxKind::NOT_KW);
+                self.bump(SyntaxKind::SIMILAR_KW);
+                self.bump(SyntaxKind::TO_KW);
+                m.complete(self, SyntaxKind::NOT_SIMILAR_TO);
+                return true;
+            }
             SyntaxKind::IS_NOT_DISTINCT_FROM => {
                 let m = self.start();
                 self.bump(SyntaxKind::IS_KW);
@@ -283,6 +403,13 @@ impl<'t> Parser<'t> {
                 m.complete(self, SyntaxKind::NOT_LIKE);
                 return true;
             }
+            SyntaxKind::NOT_ILIKE => {
+                let m = self.start();
+                self.bump(SyntaxKind::NOT_KW);
+                self.bump(SyntaxKind::ILIKE_KW);
+                m.complete(self, SyntaxKind::NOT_ILIKE);
+                return true;
+            }
             SyntaxKind::NOT_IN => {
                 let m = self.start();
                 self.bump(SyntaxKind::NOT_KW);
@@ -297,6 +424,24 @@ impl<'t> Parser<'t> {
                 m.complete(self, SyntaxKind::IS_NOT);
                 return true;
             }
+            // SyntaxKind::BYTE_STRING => {
+            //     let m = self.start();
+            //     self.bump(SyntaxKind::BYTE_STRING);
+            //     if self.eat(SyntaxKind::UESCAPE_KW) {
+            //         self.expect(SyntaxKind::STRING);
+            //     }
+            //     m.complete(self, SyntaxKind::BYTE_STRING);
+            //     return true;
+            // }
+            // SyntaxKind::IDENT => {
+            //     let m = self.start();
+            //     self.bump(SyntaxKind::IDENT);
+            //     if self.eat(SyntaxKind::UESCAPE_KW) {
+            //         self.expect(SyntaxKind::STRING);
+            //     }
+            //     m.complete(self, SyntaxKind::IDENT);
+            //     return true;
+            // }
             SyntaxKind::CUSTOM_OP => {
                 let m = self.start();
                 while !self.at(SyntaxKind::EOF) {
@@ -548,6 +693,13 @@ impl<'t> Parser<'t> {
                 SyntaxKind::LIKE_KW,
                 TrivaBetween::Allowed,
             ),
+            // not ilike
+            SyntaxKind::NOT_ILIKE => self.at_composite2(
+                n,
+                SyntaxKind::NOT_KW,
+                SyntaxKind::ILIKE_KW,
+                TrivaBetween::Allowed,
+            ),
             // not in
             SyntaxKind::NOT_IN => self.at_composite2(
                 n,
@@ -577,6 +729,58 @@ impl<'t> Parser<'t> {
                 SyntaxKind::DISTINCT_KW,
                 SyntaxKind::FROM_KW,
             ),
+            // is normalized
+            SyntaxKind::IS_NORMALIZED => {
+                if self.at(SyntaxKind::IS_KW) {
+                    if matches!(
+                        self.nth(1),
+                        SyntaxKind::NFC_KW
+                            | SyntaxKind::NFD_KW
+                            | SyntaxKind::NFKC_KW
+                            | SyntaxKind::NFKD_KW
+                    ) {
+                        if self.nth_at(2, SyntaxKind::NORMALIZED_KW) {
+                            return true;
+                        }
+                    } else {
+                        if self.nth_at(1, SyntaxKind::NORMALIZED_KW) {
+                            return true;
+                        }
+                    }
+                }
+                return false;
+            }
+            // is not normalized
+            SyntaxKind::IS_NOT_NORMALIZED => {
+                if self.at(SyntaxKind::IS_KW) && self.nth_at(1, SyntaxKind::NOT_KW) {
+                    if matches!(
+                        self.nth(2),
+                        SyntaxKind::NFC_KW
+                            | SyntaxKind::NFD_KW
+                            | SyntaxKind::NFKC_KW
+                            | SyntaxKind::NFKD_KW
+                    ) {
+                        if self.nth_at(3, SyntaxKind::NOT_KW)
+                            && self.nth_at(4, SyntaxKind::NORMALIZED_KW)
+                        {
+                            return true;
+                        }
+                    } else {
+                        if self.nth_at(2, SyntaxKind::NOT_KW)
+                            && self.nth_at(3, SyntaxKind::NORMALIZED_KW)
+                        {
+                            return true;
+                        }
+                    }
+                }
+                return false;
+            }
+            SyntaxKind::NOT_SIMILAR_TO => self.at_composite3(
+                n,
+                SyntaxKind::NOT_KW,
+                SyntaxKind::SIMILAR_KW,
+                SyntaxKind::TO_KW,
+            ),
             // similar to
             SyntaxKind::SIMILAR_TO => self.at_composite2(
                 n,
@@ -592,6 +796,80 @@ impl<'t> Parser<'t> {
                 SyntaxKind::L_PAREN,
                 TrivaBetween::Allowed,
             ),
+            // is json
+            SyntaxKind::IS_JSON => self.at_composite2(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::JSON_KW,
+                TrivaBetween::Allowed,
+            ),
+            // is not json
+            SyntaxKind::IS_NOT_JSON => self.at_composite3(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::NOT_KW,
+                SyntaxKind::JSON_KW,
+            ),
+            // is not json object
+            SyntaxKind::IS_NOT_JSON_OBJECT => self.at_composite4(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::NOT_KW,
+                SyntaxKind::JSON_KW,
+                SyntaxKind::OBJECT_KW,
+            ),
+            // is not json array
+            SyntaxKind::IS_NOT_JSON_ARRAY => self.at_composite4(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::NOT_KW,
+                SyntaxKind::JSON_KW,
+                SyntaxKind::ARRAY_KW,
+            ),
+            // is not json value
+            SyntaxKind::IS_NOT_JSON_VALUE => self.at_composite4(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::NOT_KW,
+                SyntaxKind::JSON_KW,
+                SyntaxKind::VALUE_KW,
+            ),
+            // is not json scalar
+            SyntaxKind::IS_NOT_JSON_SCALAR => self.at_composite4(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::NOT_KW,
+                SyntaxKind::JSON_KW,
+                SyntaxKind::SCALAR_KW,
+            ),
+            // is json object
+            SyntaxKind::IS_JSON_OBJECT => self.at_composite3(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::JSON_KW,
+                SyntaxKind::OBJECT_KW,
+            ),
+            // is json array
+            SyntaxKind::IS_JSON_ARRAY => self.at_composite3(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::JSON_KW,
+                SyntaxKind::ARRAY_KW,
+            ),
+            // is json value
+            SyntaxKind::IS_JSON_VALUE => self.at_composite3(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::JSON_KW,
+                SyntaxKind::VALUE_KW,
+            ),
+            // is json scalar
+            SyntaxKind::IS_JSON_SCALAR => self.at_composite3(
+                n,
+                SyntaxKind::IS_KW,
+                SyntaxKind::JSON_KW,
+                SyntaxKind::SCALAR_KW,
+            ),
             // <=
             SyntaxKind::LTEQ => self.at_composite2(
                 n,
